==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_service_get_historical_prepayments_response_200_prepayments_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_historical_prepayments_response_200_prepayments_item_perfs_item import (
    PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItemPerfsItem,
)
from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem"
)


@attr.s(auto_attribs=True)
class PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem:
    """  """

    perfs: Union[
        Unset,
        List[PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItemPerfsItem],
    ] = UNSET
    symbol: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        perfs: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.perfs, Unset):
            perfs = []
            for perfs_item_data in self.perfs:
                perfs_item = perfs_item_data.to_dict()

                perfs.append(perfs_item)

        symbol = self.symbol

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if perfs is not UNSET:
            field_dict["perfs"] = perfs
        if symbol is not UNSET:
            field_dict["symbol"] = symbol

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        perfs = []
        _perfs = d.pop("perfs", UNSET)
        for perfs_item_data in _perfs or []:
            perfs_item = PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItemPerfsItem.from_dict(
                perfs_item_data
            )

            perfs.append(perfs_item)

        symbol = d.pop("symbol", UNSET)

        pool_service_get_historical_prepayments_response_200_prepayments_item = cls(
            perfs=perfs,
            symbol=symbol,
        )

        pool_service_get_historical_prepayments_response_200_prepayments_item.additional_properties = (
            d
        )
        return pool_service_get_historical_prepayments_response_200_prepayments_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_service_get_historical_prepayments_response_200_prepayments_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_historical_prepayments_response_200_prepayments_item_values_item import (
    PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItemValuesItem,
)
from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem"
)


@attr.s(auto_attribs=True)
class PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem:
    """  """

    symbol: Union[Unset, str] = UNSET
    values: Union[
        Unset,
        List[PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItemValuesItem],
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        symbol = self.symbol
        values: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.values, Unset):
            values = []
            for values_item_data in self.values:
                values_item = values_item_data.to_dict()

                values.append(values_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if symbol is not UNSET:
            field_dict["symbol"] = symbol
        if values is not UNSET:
            field_dict["values"] = values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        symbol = d.pop("symbol", UNSET)

        values = []
        _values = d.pop("values", UNSET)
        for values_item_data in _values or []:
            values_item = PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItemValuesItem.from_dict(
                values_item_data
            )

            values.append(values_item)

        pool_service_get_historical_prepayments_response_200_prepayments_item = cls(
            symbol=symbol,
            values=values,
        )

        pool_service_get_historical_prepayments_response_200_prepayments_item.additional_properties = (
            d
        )
        return pool_service_get_historical_prepayments_response_200_prepayments_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
